@@ -5,9 +5,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2025-06-15'; # DATE
+our $DATE = '2025-10-15'; # DATE
 our $DIST = 'App-ClipboardUtils'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 use Clipboard::Any ();
 use Clone::PP qw(clone);
@@ -25,6 +25,8 @@ our %SPEC;
         schema => ['str_or_re*'],
         description => <<'MARKDOWN',
 
+Cannot be used together with `--fragments` or `--command-line` option.
+
 Note that if you supply a regex, you should not have any capture groups in the
 regex.
 
@@ -32,6 +34,44 @@ MARKDOWN
         cmdline_aliases => {s=>{}},
     };
 
+    $SPEC{add_clipboard_content}{args}{fragments} = {
+        summary => 'Only add text fragments inside content',
+        schema => ['bool*'],
+        description => <<'MARKDOWN',
+
+Cannot be used together with `--split-by` or `--command-line` option.
+
+Example content:
+
+    FAQS
+    ====
+
+    Q: Will the Thingamagic explode under extreme pressure?
+    A: No doubt.
+
+    # BEGIN clipadd id=2
+    Q: How much pressure should I apply to the Thingamagic initially?
+    A: Not that much, really. It will pressurize itself eventually.
+    # END clipadd id=2
+
+    # BEGIN clipadd id=1
+    Q: What is the appropriate age to start using the Thingamagic?
+    A: It depends on whether your kid is smart (or stupid) enough.
+    # END clipadd id=1
+
+    Q: Another question?
+    A: Another half-assed answer.
+
+Command:
+
+    % cat faq.txt | clipadd --fragments
+
+Read <pm:Text::Fragment> for more details on text fragments.
+
+MARKDOWN
+        #cmdline_aliases => {f=>{}},
+    };
+
     $SPEC{add_clipboard_content}{args}{tee} = {
         summary => 'Pass stdin to stdout',
         schema => ['true*'],
@@ -50,9 +90,9 @@ Note that when you use this option, the `--content` argument is ignored. Input
 is taken from stdin. With `--tee`, each output will be printed to stdout. After
 eof, the utility will return empty result.
 
-An example for using this option (<prog:safer> is a utility from <pm:App::safer>):
+An example for using this option:
 
-    % clipadd -c safer --tee
+    % clipadd -c safer
     Foo Bar, Co., Ltd.
     foo-bar-co-ltd
     BaZZ, Co., Ltd.
@@ -62,6 +102,10 @@ An example for using this option (<prog:safer> is a utility from <pm:App::safer>
 MARKDOWN
         cmdline_aliases => {c=>{}},
     };
+
+    $SPEC{add_clipboard_content}{args_rels}{"choose_one&"} = [
+        [qw/command_line split_by fragments/],
+    ];
 }
 
 sub add_clipboard_content {
@@ -133,6 +177,28 @@ sub add_clipboard_content {
             }
             $res->[3]{'func.parts'} = @split_parts;
             $res;
+        } elsif ($args{fragments}) {
+            require Text::Fragment;
+            my $lfres = Text::Fragment::list_fragments(text => $content, label => "clipadd");
+            return [500, "Can't list fragments in content: $lfres->[0] - $lfres->[1]"]
+                unless $lfres->[0] == 200;
+            my @parts = map { $_->{payload} } sort { $a->{id} <=> $b->{id} } @{ $lfres->[2] };
+
+            my $res = [204, "OK (no content)"];
+            for my $part (@parts) {
+                if ($tee) {
+                    print $part;
+                }
+
+                # do not add empty part to clipboard
+                if (length $part) {
+                    $res = Clipboard::Any::add_clipboard_content(
+                        %args, content => $part,
+                    ); # currently we use the last add_clipboard_content status
+                }
+            }
+            $res->[3]{'func.parts'} = @parts;
+            $res;
         } else {
             print $content if $tee;
             Clipboard::Any::add_clipboard_content(%args);
@@ -164,7 +230,7 @@ App::ClipboardUtils - CLI utilities related to clipboard
 
 =head1 VERSION
 
-This document describes version 0.011 of App::ClipboardUtils (from Perl distribution App-ClipboardUtils), released on 2025-06-15.
+This document describes version 0.012 of App::ClipboardUtils (from Perl distribution App-ClipboardUtils), released on 2025-10-15.
 
 =head1 DESCRIPTION
 
@@ -222,6 +288,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<chomp_newline> => I<bool>
+
+Remove trailing newlines before adding item to clipboard.
+
 =item * B<clipboard_manager> => I<str>
 
 Explicitly set clipboard manager to use.
@@ -236,9 +306,9 @@ Note that when you use this option, the C<--content> argument is ignored. Input
 is taken from stdin. With C<--tee>, each output will be printed to stdout. After
 eof, the utility will return empty result.
 
-An example for using this option (L<safer> is a utility from L<App::safer>):
+An example for using this option:
 
- % clipadd -c safer --tee
+ % clipadd -c safer
  Foo Bar, Co., Ltd.
  foo-bar-co-ltd
  BaZZ, Co., Ltd.
@@ -249,10 +319,45 @@ An example for using this option (L<safer> is a utility from L<App::safer>):
 
 (No description)
 
+=item * B<fragments> => I<bool>
+
+Only add text fragments inside content.
+
+Cannot be used together with C<--split-by> or C<--command-line> option.
+
+Example content:
+
+ FAQS
+ ====
+ 
+ Q: Will the Thingamagic explode under extreme pressure?
+ A: No doubt.
+ 
+ # BEGIN clipadd id=2
+ Q: How much pressure should I apply to the Thingamagic initially?
+ A: Not that much, really. It will pressurize itself eventually.
+ # END clipadd id=2
+ 
+ # BEGIN clipadd id=1
+ Q: What is the appropriate age to start using the Thingamagic?
+ A: It depends on whether your kid is smart (or stupid) enough.
+ # END clipadd id=1
+ 
+ Q: Another question?
+ A: Another half-assed answer.
+
+Command:
+
+ % cat faq.txt | clipadd --fragments
+
+Read L<Text::Fragment> for more details on text fragments.
+
 =item * B<split_by> => I<str_or_re>
 
 Split content by specified stringE<sol>regex, add the split content as multiple clipboard entries.
 
+Cannot be used together with C<--fragments> or C<--command-line> option.
+
 Note that if you supply a regex, you should not have any capture groups in the
 regex.
 
@@ -291,6 +396,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<chomp_newline> => I<bool>
+
+Remove trailing newlines before adding item to clipboard.
+
 =item * B<clipboard_manager> => I<str>
 
 Explicitly set clipboard manager to use.
